@@ -3,7 +3,7 @@
 BigInt &BigInt::rshift()
 {
     if (!BN_rshift1(&d_bn, &d_bn))
-        throw Errno("BigInt::rshift() failed");
+        throw Exception() << "BigInt::rshift() failed";
 
     return *this;
 }
